@@ -1,7 +1,7 @@
 package Complete::Util;
 
 our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -140,6 +140,13 @@ $SPEC{complete_array_elem} = {
     summary => 'Complete from array',
     description => <<'_',
 
+Try to find completion from an array of strings. Will attempt several methods,
+from the cheapest and most discriminating to the most expensive and least
+discriminating: normal string prefix matching, word-mode matching (see
+`Complete::Common::OPT_WORD_MODE` for more details), char-mode matching (see
+`Complete::Common::OPT_CHAR_MODE` for more details), and fuzzy matching (see
+`Complete::Common::OPT_FUZZY` for more details).
+
 Will sort the resulting completion list, so you don't have to presort the array.
 
 _
@@ -182,10 +189,11 @@ sub complete_array_elem {
     my $array     = $args{array} or die "Please specify array";
     my $word      = $args{word} // "";
 
-    my $ci        = $Complete::Common::OPT_CI;
-    my $map_case  = $Complete::Common::OPT_MAP_CASE;
-    my $word_mode = $Complete::Common::OPT_WORD_MODE;
-    my $fuzzy     = $Complete::Common::OPT_FUZZY;
+    my $ci          = $Complete::Common::OPT_CI;
+    my $map_case    = $Complete::Common::OPT_MAP_CASE;
+    my $word_mode   = $Complete::Common::OPT_WORD_MODE;
+    my $char_mode   = $Complete::Common::OPT_CHAR_MODE // 1;
+    my $fuzzy       = $Complete::Common::OPT_FUZZY;
 
     return [] unless @$array;
 
@@ -221,8 +229,8 @@ sub complete_array_elem {
     my @words; # the answer
     my @arrayn; # case- & map-case-normalized form of $array (+rmap entries)
 
-    # normal (non-fuzzy, non-word-mode) matching. we also fill @arrayn here
-    # (which will be used again in word-mode & fuzzy matching) so we don't have
+    # normal string prefix matching. we also fill @arrayn here (which will be
+    # used again in word-mode, fuzzy, and char-mode matching) so we don't have
     # to calculate again.
     for my $el (@$array) {
         my $eln = $ci ? uc($el) : $el; $eln =~ s/_/-/g if $map_case;
@@ -239,6 +247,7 @@ sub complete_array_elem {
         }
     }
 
+    # word-mode matching
     {
         last unless $word_mode && !@words;
         my @split_wordn = $wordn =~ /(\w+)/g;
@@ -274,6 +283,16 @@ sub complete_array_elem {
         }
     }
 
+    # char-mode matching
+    if ($char_mode && !@words && length($wordn) && length($wordn) <= 7) {
+        my $re = join(".*", map {quotemeta} split(//, $wordn));
+        $re = qr/$re/;
+        for my $i (0..$#arrayn) {
+            push @words, $array->[$i] if $arrayn[$i] =~ $re;
+        }
+    }
+
+    # fuzzy matching
     if ($fuzzy && !@words) {
         $code_editdist //= do {
             if (eval { require Text::Levenshtein::XS; 1 }) {
@@ -477,7 +496,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.43 of Complete::Util (from Perl distribution Complete-Util), released on 2016-01-05.
+This document describes version 0.44 of Complete::Util (from Perl distribution Complete-Util), released on 2016-01-05.
 
 =head1 DESCRIPTION
 
@@ -543,6 +562,13 @@ answer will be merged.
 
 Complete from array.
 
+Try to find completion from an array of strings. Will attempt several methods,
+from the cheapest and most discriminating to the most expensive and least
+discriminating: normal string prefix matching, word-mode matching (see
+C<Complete::Common::OPT_WORD_MODE> for more details), char-mode matching (see
+C<Complete::Common::OPT_CHAR_MODE> for more details), and fuzzy matching (see
+C<Complete::Common::OPT_FUZZY> for more details).
+
 Will sort the resulting completion list, so you don't have to presort the array.
 
 This function is not exported by default, but exportable.
@@ -637,7 +663,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
 
 =head1 BUGS
 
